==> jc-1.4.0.tar.gz: java/awt/JobAttributes__24DestinationType.h <==
// public final class java.awt.JobAttributes$DestinationType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 6436a84d012a38d2 java_awt_JobAttributes__24DestinationType
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24DestinationType_H_
#define _JC_java_awt_JobAttributes__24DestinationType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24DestinationType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24DestinationType$sub_refs	_jc_java_awt_JobAttributes__24DestinationType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs	_jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$refs	_jc_java_awt_JobAttributes__24DestinationType$refs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$nonrefs	_jc_java_awt_JobAttributes__24DestinationType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$object	_jc_java_awt_JobAttributes__24DestinationType$object;

typedef struct _jc_java_awt_JobAttributes__24DestinationType$fields_struct	_jc_java_awt_JobAttributes__24DestinationType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vmethods	_jc_java_awt_JobAttributes__24DestinationType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vtable	_jc_java_awt_JobAttributes__24DestinationType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vtype	_jc_java_awt_JobAttributes__24DestinationType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24DestinationType$fields_struct {
	struct _jc_java_awt_JobAttributes__24DestinationType$object	*FILE;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24DestinationType$object	*PRINTER;
};
extern _jc_java_awt_JobAttributes__24DestinationType$fields_struct _jc_java_awt_JobAttributes__24DestinationType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24DestinationType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24DestinationType$object *, jint);

// Static methods
extern void _jc_java_awt_JobAttributes__24DestinationType$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24DestinationType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24DestinationType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24DestinationType$vmethods	java_awt_JobAttributes__24DestinationType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24DestinationType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24DestinationType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DestinationType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DestinationType$refs {
    _jc_java_awt_JobAttributes__24DestinationType$sub_refs	java_awt_JobAttributes__24DestinationType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DestinationType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs	java_awt_JobAttributes__24DestinationType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24DestinationType$object {
	_jc_java_awt_JobAttributes__24DestinationType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24DestinationType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24DestinationType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24DestinationType$vtype _jc_java_awt_JobAttributes__24DestinationType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24DestinationType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24DestinationType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24DestinationType_H_ */

==> jc-1.4.6.tar.gz: java/awt/JobAttributes__24DestinationType.h <==
// public final class java.awt.JobAttributes$DestinationType

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 6436a84d012a38d2 java_awt_JobAttributes__24DestinationType
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_JobAttributes__24DestinationType_H_
#define _JC_java_awt_JobAttributes__24DestinationType_H_

// Forward structure declarations
struct _jc_java_awt_JobAttributes__24DestinationType$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_JobAttributes__24DestinationType$sub_refs	_jc_java_awt_JobAttributes__24DestinationType$sub_refs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs	_jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$refs	_jc_java_awt_JobAttributes__24DestinationType$refs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$nonrefs	_jc_java_awt_JobAttributes__24DestinationType$nonrefs;
typedef struct _jc_java_awt_JobAttributes__24DestinationType$object	_jc_java_awt_JobAttributes__24DestinationType$object;

typedef struct _jc_java_awt_JobAttributes__24DestinationType$fields_struct	_jc_java_awt_JobAttributes__24DestinationType$fields_struct;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vmethods	_jc_java_awt_JobAttributes__24DestinationType$vmethods;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vtable	_jc_java_awt_JobAttributes__24DestinationType$vtable;
typedef const struct _jc_java_awt_JobAttributes__24DestinationType$vtype	_jc_java_awt_JobAttributes__24DestinationType$vtype;

// Class fields structure
struct _jc_java_awt_JobAttributes__24DestinationType$fields_struct {
	struct _jc_java_awt_JobAttributes__24DestinationType$object	*FILE;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_JobAttributes__24DestinationType$object	*PRINTER;
};
extern _jc_java_awt_JobAttributes__24DestinationType$fields_struct _jc_java_awt_JobAttributes__24DestinationType$class_fields;

// Constructors
extern void _jc_java_awt_JobAttributes__24DestinationType$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_JobAttributes__24DestinationType$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_JobAttributes__24DestinationType$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_JobAttributes__24DestinationType$vmethods {
};

// Vtable
struct _jc_java_awt_JobAttributes__24DestinationType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_JobAttributes__24DestinationType$vmethods	java_awt_JobAttributes__24DestinationType;
};

// Vtype
struct _jc_java_awt_JobAttributes__24DestinationType$vtype {
	_jc_type			type;
	_jc_java_awt_JobAttributes__24DestinationType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DestinationType$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DestinationType$refs {
    _jc_java_awt_JobAttributes__24DestinationType$sub_refs	java_awt_JobAttributes__24DestinationType;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_JobAttributes__24DestinationType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_JobAttributes__24DestinationType$sub_nonrefs	java_awt_JobAttributes__24DestinationType;
};

// Object instance structure
struct _jc_java_awt_JobAttributes__24DestinationType$object {
	_jc_java_awt_JobAttributes__24DestinationType$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_JobAttributes__24DestinationType$vtype	*vtype;
	_jc_java_awt_JobAttributes__24DestinationType$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_JobAttributes__24DestinationType$vtype _jc_java_awt_JobAttributes__24DestinationType$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_JobAttributes__24DestinationType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_JobAttributes__24DestinationType$class_object;

#endif	/* _JC_java_awt_JobAttributes__24DestinationType_H_ */
